using System;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Drawing.Text;
using System.Collections;
using System.Collections.Specialized;
using System.ComponentModel;
using System.Windows.Forms;
using System.Data;
using System.Runtime.InteropServices;
using System.Data.OleDb;
using oktellClient.Controls;
using oktellClient;
using System.Reflection;
using oktell.Objects;

namespace OktellPlugin
{
	/// <summary>
	///   .  (29  2009.)
	/// </summary>
	public class oktellControlBox :Control
	{
		#region Events
		public event EventHandler OnButtonClick;
		#endregion

		#region Classes
		public class ControlButton
		{
			public Bitmap ButtonUp = null;
			public Bitmap ButtonOver = null;
			public Bitmap ButtonDown = null;
			public object Tag = null;
			public string Hint = "";
		}
		#endregion

		#region Fields
		private ToolTip tool = new ToolTip();
		public ControlButton[] Buttons = new ControlButton[0];
		#endregion

		#region Properties
		private int m_ButtonSize = 14;
		public int ButtonSize
		{
			get
			{
				return m_ButtonSize;
			}
			set
			{
				if ( m_ButtonSize != value )
				{
					m_ButtonSize = value;
					Invalidate();
				}
			}
		}
		private int m_ButtonMargin = 1;
		public int ButtonMargin
		{
			get
			{
				return m_ButtonMargin;
			}
			set
			{
				if ( m_ButtonMargin != value )
				{
					m_ButtonMargin = value;
					Invalidate();
				}
			}
		}
		#endregion

		#region Constructor / Destructor
		public oktellControlBox()
		{
			this.Bounds = new Rectangle ( new Point ( 0, 0 ), new Size ( m_ButtonSize, m_ButtonSize ) );
			this.Anchor = AnchorStyles.Top | AnchorStyles.Right;
			SetStyle ( ControlStyles.AllPaintingInWmPaint | ControlStyles.DoubleBuffer | ControlStyles.UserPaint | ControlStyles.ResizeRedraw, true );
		}

		protected override void Dispose(bool disposing)
		{
			try
			{
				base.Dispose (disposing);
				tool.Dispose();
			}
			catch{}
		}
		#endregion

		#region Methods
		protected override void OnPaint(PaintEventArgs e)
		{
			try
			{
				if ( Buttons != null )
				{

					Bitmap bmp = null;

					#region -   MouseOver   ,   (      )
					Point point = this.PointToClient ( MousePosition );
					int num = ButtonNumber ( point.X, point.Y );
					if (num == -1)
						m_MouseOver = -1;
					#endregion

					for ( int i = 0; i < Buttons.Length; i++ )
					{
						if (i == m_MouseDown)
						{
							if (m_MouseDown == m_MouseOver)
							{
								bmp = Buttons[i].ButtonDown;

								if (bmp == null)
									bmp = Buttons[i].ButtonOver;

								if (bmp == null)
									bmp = Buttons[i].ButtonUp;
							}
							else
								bmp = Buttons[i].ButtonUp; 
						}
						else if ( (i == m_MouseOver) && (m_MouseDown==-1) )
						{
							bmp = Buttons[i].ButtonOver;

							if (bmp == null)
								bmp = Buttons[i].ButtonUp;
						}
						else
							bmp = Buttons[i].ButtonUp;


						if (bmp != null)
							CGraphic.DrawResourceImage ( e.Graphics, bmp, new Rectangle ( this.Width-(i+1)*m_ButtonSize-i*m_ButtonMargin, 0, m_ButtonSize, m_ButtonSize ) );
					}
				}
			}
			catch (Exception ex)
			{
				string s = ex.ToString();
			}
		}

		/// <summary>
		///   ,    -1
		/// </summary>
		/// <param name="MouseX"></param>
		/// <param name="MouseY"></param>
		/// <returns></returns>
		private int ButtonNumber ( int MouseX, int MouseY )
		{
			int num;
			if ( (MouseY>=0) && (MouseY<m_ButtonSize) && (MouseX<this.Width) && (MouseX >= this.Width-Buttons.Length*m_ButtonSize-(Buttons.Length-1)*m_ButtonMargin) )
				num = (this.Width-MouseX-1)/(m_ButtonSize+m_ButtonMargin);
			else
				num = -1;

			if (MouseX >= this.Width-(num+1)*m_ButtonSize-num*m_ButtonMargin)
				return num;
			else
				return -1;
		}

		private int m_MouseOver = -1;
		protected override void OnMouseMove(MouseEventArgs e)
		{
			base.OnMouseMove (e);

			int num = ButtonNumber ( e.X, e.Y );

			//. 
			if ( ( Control.MouseButtons & MouseButtons.Left ) == 0 )
				m_MouseDown = -1;
				
			//				if ( m_MouseDown != -1 )
			//				{
			//					if ( m_MouseDown != num )
			//						Invalidate();
			//					return;
			//				}

			if (m_MouseOver != num )
			{
				tool.Active = false;
				tool.Active = true;
				if ( (num!=-1) && (Buttons[num].Hint != null) && (Buttons[num].Hint!="") )
					tool.SetToolTip ( this, Buttons[num].Hint );

				m_MouseOver = num;
				Invalidate();
			}
		}
		protected override void OnMouseLeave(EventArgs e)
		{
			base.OnMouseLeave (e);

			if ( m_MouseOver != -1 )
			{
				m_MouseOver = -1;
				Invalidate();
			}
		}

		private int m_MouseDown = -1;
		protected override void OnMouseDown(MouseEventArgs e)
		{
			base.OnMouseDown (e);

			if (e.Button != MouseButtons.Left)
				return;

			int num = ButtonNumber ( e.X, e.Y );

			m_MouseDown = num;

			if ( num != -1 )
				Invalidate();
		}

		protected override void OnMouseUp(MouseEventArgs e)
		{
			base.OnMouseUp (e);

			if (e.Button != MouseButtons.Left)
				return;

			int num = ButtonNumber ( e.X, e.Y );

			if (m_MouseDown != -1)
			{
				if ( m_MouseDown == num )
				{
					m_MouseOver = -1;
					m_MouseDown = -1;
					Invalidate();
					if ( OnButtonClick != null )
						OnButtonClick ( Buttons[num], new EventArgs() );
				}
				else
				{
					m_MouseDown = -1;
					Invalidate();
				}
			}
		}

		#endregion
	}

	/// <summary>
	/// Summary description for oktellSmallTabPanel.
	/// </summary>
	public class oktellSmallTabPanel : System.Windows.Forms.UserControl
	{		
		#region Private members
		
		private PictureBoxMovingForm pb;
		private System.ComponentModel.Container components = null;

		private string m_Caption = "#";
		private bool m_DrawLogo = false;
		private bool m_AutoMakeTop = true;
		private Bitmap m_Bmp = null;
		private Graphics m_Gr = null;
		private RectangleF m_StrRect;
		private Font m_CaptionFont, m_TabActiveFont, m_TabUnactiveFont;
		private StringCollection m_Tabs = new StringCollection();
		private ArrayList m_Rects = new ArrayList();
		private ArrayList m_TABS = new ArrayList ( );
		private Point[] m_points =new Point[4];
		private int m_ActiveTabIndex = -1;		
		private const int m_MaxOffset = 170;
		private const int m_MinOffset = 25;		
		private int m_FirstTabOffset = m_MaxOffset;
		private int m_BorderWidth = 12;
		private int m_Zazor = 2;
		private int m_RightBound = m_MaxOffset;
		private bool m_MinButton = false;
		private bool m_MaxButton = false;
		private bool m_CenterText = false;
		private int m_ScrollOffsX = 0;	

		private System.Windows.Forms.Timer m_BlinkTimer;
		#endregion
		
		#region Constructor & Destructor
		public oktellSmallTabPanel()
		{	
			SetStyle(ControlStyles.DoubleBuffer | ControlStyles.AllPaintingInWmPaint | ControlStyles.UserPaint , true);

			CreateGraphicsObj();
			
			InitializeComponent();

			#region  

			ctrlBox.OnButtonClick +=new EventHandler(ctrlBox_OnButtonClick);

			UpdateCtrlBox();

			#endregion

			this.Font = CGraphic.UpdateFont ( this.Font, CGraphic.DefaultFontSize );
			this.FontCaption = CGraphic.GetFont ( 15F );
			this.FontTabActive = CGraphic.GetFont ( CGraphic.DefaultFontSize, FontStyle.Regular );
			this.FontTabInactive = CGraphic.GetFont ( CGraphic.DefaultFontSize, FontStyle.Regular );

			Dock = DockStyle.Top;

			Height = 50;

			pb.Image = m_Bmp;

			AutoDrawControl();
		}

		/// <summary> 
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			
			DestroyGraphics();

			base.Dispose( disposing );
		}

		#region Component Designer generated code
		/// <summary> 
		/// Required method for Designer support - do not modify 
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			this.pb = new oktellClient.Controls.PictureBoxMovingForm();
			this.SuspendLayout();
			// 
			// pb
			// 
			this.pb.CanDragForm = true;
			this.pb.Dock = System.Windows.Forms.DockStyle.Fill;
			this.pb.Font = new System.Drawing.Font("Microsoft Sans Serif", 11F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Pixel);
			this.pb.Location = new System.Drawing.Point(0, 0);
			this.pb.Name = "pb";
			this.pb.Size = new System.Drawing.Size(544, 150);
			this.pb.TabIndex = 0;
			this.pb.TabStop = false;
			this.pb.MouseUp += new System.Windows.Forms.MouseEventHandler(this.pb_MouseUp);
			this.pb.DoubleClick += new System.EventHandler(this.pb_DoubleClick);
			this.pb.MouseMove += new System.Windows.Forms.MouseEventHandler(this.pb_MouseMove);
			this.pb.MouseDown += new System.Windows.Forms.MouseEventHandler(this.pb_MouseDown);
			this.pb.VisibleChanged += new EventHandler(this.pb_VisibleChanged);
			// 
			// oktellSmallTabPanel
			// 
			this.BackColor = System.Drawing.Color.White;
			this.Controls.Add(this.pb);
			this.Name = "oktellSmallTabPanel";
			this.Size = new System.Drawing.Size(544, 150);
			this.VisibleChanged += new EventHandler(oktellSmallTabPanel_VisibleChanged);
			this.ResumeLayout(false);			

		}
		#endregion
		#endregion

		#region Public fields
		public Font FontCaption
		{
			get { return (m_CaptionFont != null) ? m_CaptionFont : this.Font; }
			set 
			{ 
				m_CaptionFont = value; 
				
				DrawCaption();
				pb.Invalidate();
			}
		}
		
		public Font FontTabActive
		{
			get { return (m_TabActiveFont != null) ? m_TabActiveFont : this.Font; }
			set 
			{ 
				m_TabActiveFont = value; 
				DrawCaption();
				pb.Invalidate();
			}
		}
		
		public Font FontTabInactive
		{
			get { return (m_TabUnactiveFont != null) ? m_TabUnactiveFont : this.Font; }
			set 
			{ 
				m_TabUnactiveFont = value; 
				DrawCaption();
				pb.Invalidate();
			}
		}

		public string Caption
		{
			get
			{
				return m_Caption;
			}
			set
			{
				if ( m_Caption != value )
				{
					m_Caption = value;					
					AutoDrawControl();
				}
			}
		}
		
		public bool DrawLogo
		{
			get { return m_DrawLogo; }
			set 
			{
				m_DrawLogo = value;
				AutoDrawControl();
			}
		}
		public bool AutoMakeTopDock
		{
			get { return m_AutoMakeTop; }
			set { m_AutoMakeTop = value; }
		}
		public int ActiveTabIndex
		{
			get
			{
				return (m_ActiveTabIndex);
			}
			set
			{
				m_ActiveTabIndex = value;
				
				#region   
				if (( m_ActiveTabIndex >= 0 ) && ( m_TABS.Count > m_ActiveTabIndex ))
				{
					CTabInfo ti = m_TABS [ m_ActiveTabIndex ] as CTabInfo;					
					RectangleF rshift = ti.Rect;
					rshift.Offset ( - m_ScrollOffsX, 0 );
					if ( rshift.Left < 20 )				
						m_ScrollOffsX -= 20 - (int) rshift.Left;
					else if ( rshift.Right > pb.ClientSize.Width - 20 )
						m_ScrollOffsX += (int) rshift.Right - pb.ClientSize.Width - 20;
				}
				#endregion

				//DrawControl();
				AutoDrawControl();
				OnTabChange();
			}
		}

		public bool MinButton
		{
			get { return m_MinButton; }
			set 
			{ 
				if (m_MinButton != value)
				{
					m_MinButton = value;
					UpdateCtrlBox();
				}
				if ( DesignMode )
				{
					DrawControl();
					pb.Invalidate();
				}
			}
		}

		public bool MaxButton
		{
			get { return m_MaxButton; }
			set 
			{ 
				if (m_MaxButton != value)
				{
					m_MaxButton = value;
					UpdateCtrlBox();
				}
				if ( DesignMode )
				{
					DrawControl();
					pb.Invalidate();
				}
			}
		}

		public bool CenterText 
		{
			get { return m_CenterText; }
			set 
			{ 
				m_CenterText = value; 
				if ( DesignMode )
				{
					DrawControl();
					pb.Invalidate();
				}
			}
		}

		public event EventHandler TabChange;
		public event EventHandler OnCrossClicked;
		//public event CancelEventHandler ValidateTabChanging = null;
		#endregion

		#region Private methods
		private void OnTabChange()
		{
			if (TabChange != null)
			{
				TabChange(this, EventArgs.Empty);
			}
		}

		private void BuildTabsRect()
		{
			if (( pb.ClientSize.Width == 0 ) && ( pb.ClientSize.Height == 0 ))
				return;

			int dx = pb.ClientSize.Width - m_RightBound + m_FirstTabOffset - 25;
			if ( dx != m_FirstTabOffset && m_TABS.Count > 0 )
			{
				if (dx > m_MinOffset && dx < m_MaxOffset )
				{
					m_FirstTabOffset = dx;
				}
				else
				{
					if ( dx >= m_MaxOffset )
						m_FirstTabOffset = m_MaxOffset;
					else
						m_FirstTabOffset = m_MinOffset;
				}
				int x = m_FirstTabOffset + m_BorderWidth;

				for ( int i = 0; i < m_TABS.Count; i++ )
				{
					CTabInfo ti = m_TABS [ i ] as CTabInfo;
					ti.Rect.X = x;					
					x = (int)( 2 * m_BorderWidth + m_Zazor + ti.Rect.Right );
				}

				CTabInfo tni = m_TABS [ m_TABS.Count - 1 ] as CTabInfo;
				m_RightBound = (int)( tni.Rect.Right + 2 * m_BorderWidth ); 
			}
		}

		int dstx = 10;
		int dsty = 10;
		int w1 = 3;
		int minoffset = 13;


		private int clickpos = 0;
		private int pb_WhereClicked ( System.Windows.Forms.MouseEventArgs e )
		{
			int tmp = 0;

			if ( e.Button == MouseButtons.Left )
			{				
				// 
				//				if (( e.X >= this.Width - dstx - w1 ) && ( e.X <= this.Width - dstx + w1 ))
				//					if (( e.Y >= dsty - w1 ) && ( e.Y <= dsty + w1 ))
				//					{
				//						tmp = 100;
				//						return tmp;
				//					}
				//
				//				if ( m_MaxButton )
				//				{
				//					if (( e.Y >= dsty - w1 ) && ( e.Y <= dsty + w1 ))
				//					{
				//						if (( e.X >= this.Width - dstx - minoffset - w1 ) && ( e.X <= this.Width - dstx - minoffset + w1 ))
				//						{
				//							tmp = 101;
				//							return tmp;								
				//						}
				//					}
				//				}
				//
				//				if ( m_MinButton )
				//				{					
				//					if (( e.Y >= dsty - w1 ) && ( e.Y <= dsty + w1 ))
				//					{
				//						int offsextra = m_MaxButton ? minoffset : 0;
				//						if (( e.X >= this.Width - dstx - minoffset - offsextra - w1 ) && ( e.X <= this.Width - dstx - minoffset - offsextra + w1 ))
				//						{
				//							tmp = 102;								
				//							return tmp;
				//						}					
				//					}
				//				}

				if ( m_LeftShiftTabs )
				{
					Point ct = new Point ( 3, pb.ClientSize.Height - m_TabHeight / 2 - 2 );
					if (( e.Y > ct.Y - 5 ) && ( e.Y < ct.Y + 5 ))
						if (( e.X > ct.X - 2 ) && ( e.X < ct.X + 20 ))
						{
							tmp = 111;
							return tmp;
						}
				}

				if ( m_RightShiftTabs )
				{
					Point ct = new Point ( pb.ClientSize.Width - 3, pb.ClientSize.Height - m_TabHeight / 2 - 2 );
					if (( e.Y > ct.Y - 5 ) && ( e.Y < ct.Y + 5 ))
						if (( e.X > ct.X - 20 ) && ( e.X < ct.X + 2 ))
						{
							tmp = 112;
							return tmp;
						}
				}

				if ( m_TABS.Count == 0 )
				{
					tmp = 0;
					return tmp;
				}
				else
				{
					for ( int i = 0; i < m_TABS.Count; i++ )
					{
						CTabInfo ti = m_TABS [ i ] as CTabInfo;						
						RectangleF r1 = ti.Rect;
						r1.Offset ( - m_ScrollOffsX, 0 );
						if ( r1.Contains ( new PointF ( e.X, e.Y )))
						{
							tmp = i + 1;
							return tmp;							
						}
					}
				}
			}

			return tmp;
		}

		private void pb_MouseDown(object sender, System.Windows.Forms.MouseEventArgs e)
		{
			clickpos = pb_WhereClicked ( e );
			if ( clickpos > 110 )
			{
				if ( clickpos == 111 )
					m_ScrollOffsX -= m_OneClickShift;
				else if ( clickpos == 112 )
					m_ScrollOffsX += m_OneClickShift;
				
				DrawBackTabs ( );
				DrawTabs ( );
				pb.Invalidate();

				clickpos = 0;
				return;
			}
			if ( clickpos > 0 )
			{
				pb.CanDragForm = false;
				m_CanMaximize = false;
				return;
			}

			m_CanMaximize = false;

			bool maximized = ( ParentForm.Width == Screen.GetWorkingArea ( ParentForm.Bounds ).Width ) && ( ParentForm.Height == Screen.GetWorkingArea ( ParentForm.Bounds ).Height );
			if ( ParentForm is oktellResizableFormByFrame )
				maximized = ( ParentForm as oktellResizableFormByFrame ).IsMaximized;
			
			pb.CanDragForm = true && ( ! maximized );

			//    dblclick
			m_CanMaximize = true;
		}

		private void pb_MouseUp(object sender, System.Windows.Forms.MouseEventArgs e)
		{
			int newclickpos = pb_WhereClicked ( e );
			if (( clickpos != newclickpos ) || ( clickpos == 0 ))
				return;

			switch ( clickpos )
			{
					// 
					//				case 100:
					//					if ( OnCrossClicked != null )
					//						OnCrossClicked ( this, EventArgs.Empty );
					//					else
					//						ParentForm.Close ( );
					//					break;
					//
					//				case 101:
					//					Type t = this.ParentForm.GetType ( );
					//					MethodInfo mi = t.GetMethod ( "Maximize" );
					//					if ( mi != null )							
					//						mi.Invoke ( ParentForm, null );
					//					break;
					//
					//				case 102:
					//					this.ParentForm.WindowState = FormWindowState.Minimized;
					//					break;

				default:
					ActiveTabIndex = clickpos - 1;
					break;
			}
		}
	
		#endregion

		#region Drawing
		private void CreateGraphicsObj()
		{	
			m_Bmp = new Bitmap(this.ClientSize.Width, this.ClientSize.Height);
			m_Gr = Graphics.FromImage(m_Bmp);
			m_Gr.TextRenderingHint = CGraphic.TextRenderingHint;
			m_Gr.SmoothingMode  = SmoothingMode.AntiAlias;
			SizeF sz = m_Gr.MeasureString ( "WhpgYj", FontCaption, 200 );
			m_StrRect = new RectangleF(15, ( m_Bmp.Height - (int) Math.Ceiling ( sz.Height ) ) / 2, m_Bmp.Width - 30, (int) Math.Ceiling ( sz.Height ) );
		}

		private void DestroyGraphics()
		{
			if (m_Gr != null)
			{
				m_Gr.Dispose();
			}
			if (m_Bmp != null)
			{
				m_Bmp.Dispose();
			}			
		}
		
		private void DrawControl()
		{	
			// 

			try
			{
				DrawBack ( );
				DrawTabs();
				DrawCaption();
				//			DrawCross ( );
				//			DrawMin ( );

				pb.Invalidate();
			}
			catch ( Exception ex )
			{
				ClientStatic.Log ( ex );
			}
		}

		private void DrawBack ( )
		{
			try
			{
				//if ( ! pb.IsHandleCreated )
				//	return;
				if (( pb.ClientSize.Width <= 0 ) || ( pb.ClientSize.Height <= 0 ))
					return;

				SolidBrush br = new SolidBrush ( pb.BackColor );
				m_Gr.FillRectangle ( br, 0, 0, pb.ClientSize.Width, pb.ClientSize.Height );
				br.Dispose();
			}
			catch ( Exception ex )
			{
				ClientStatic.Log ( ex );
			}
		}

		private void DrawCaption()
		{
			try
			{
				//				if ( ! pb.IsHandleCreated )
				//					return;
				if (( pb.ClientSize.Width <= 0 ) || ( pb.ClientSize.Height <= 0 ))
					return;

				if (( Dock != DockStyle.Top ) && ( m_AutoMakeTop ))
					Dock = DockStyle.Top;

				SizeF sz = m_Gr.MeasureString ( "WhpgYj", FontCaption, 200 );
				m_StrRect = new RectangleF ( 10, ( pb.ClientSize.Height - (int) Math.Ceiling ( sz.Height ) ) / 2 - ( m_CenterText ? 0 : 5 ), pb.ClientSize.Width - 30, (int) Math.Ceiling ( sz.Height ) );

				m_Gr.TextRenderingHint = TextRenderingHint.AntiAlias;
			
				//			using (SolidBrush br = new SolidBrush(pb.BackColor))
				//			{
				//				m_Gr.FillRectangle(br, m_StrRect);
				//			}

				if ( m_DrawLogo )
					CGraphic.DrawLogo ( this, m_Gr, 18, 20, 15 );
				else
					m_Gr.DrawString(m_Caption, FontCaption, Brushes.White, m_StrRect);
			}
			catch ( Exception ex )
			{
				ClientStatic.Log ( ex );
			}
		}


		private bool m_LeftShiftTabs = false;
		private bool m_RightShiftTabs = false;
		private int m_TabHeight = 17;
		private int m_OneClickShift = 80;

		private void DrawBackTabs ( )
		{
			try
			{
				//				if ( ! pb.IsHandleCreated )
				//					return;
				if (( pb.ClientSize.Width <= 0 ) || ( pb.ClientSize.Height <= 0 ))
					return;

				SolidBrush br = new SolidBrush ( pb.BackColor );
				m_Gr.FillRectangle ( br, 0, pb.ClientSize.Height - m_TabHeight - 1, pb.ClientSize.Width, m_TabHeight + 1 );
				br.Dispose();
			}
			catch ( Exception ex )
			{
				ClientStatic.Log ( ex );
			}
		}	
	
		private void DrawTabs()
		{
			try
			{
				//				if ( ! pb.IsHandleCreated )
				//					return;
				if (( pb.ClientSize.Width <= 0 ) || ( pb.ClientSize.Height <= 0 ))
					return;

				if ( m_TABS.Count == 0 ) 
					return;
			
				//			SolidBrush br = new SolidBrush ( pb.BackColor );
				//			m_Gr.FillRectangle ( br, 0, pb.ClientSize.Height - 22, pb.ClientSize.Width, 22 );
				//			br.Dispose();
			
				int x = 0, w;
			
				x = m_FirstTabOffset;
				RectangleF rfshift;

				m_Gr.TextRenderingHint = CGraphic.TextRenderingHint;

				m_LeftShiftTabs = false;
				m_RightShiftTabs = false;
				int rcnt = 0;
				int lcnt = 0;
			
				for ( int i = 0; i < m_TABS.Count; i++ )
				{
					CTabInfo ti = m_TABS [ i ] as CTabInfo;

					rfshift = ti.Rect;
					rfshift.Offset ( - m_ScrollOffsX, 0 );

					w = (int) rfshift.Width + 2 * m_BorderWidth;
					x = (int) rfshift.X - m_BorderWidth;
				
					#region   
					int delta = 5;
					if ( x - delta > pb.ClientSize.Width - 24 )					
					{
						rcnt++;
						m_RightShiftTabs = true;
						continue;
					}

					if ( x + w + delta < 24 )
					{
						lcnt++;
						m_LeftShiftTabs = true;
						continue;
					}

					if ( x - delta < 10 )
					{
						lcnt++;
						m_LeftShiftTabs = true;
					}

					if ( x + w + delta > pb.ClientSize.Width - 10 )
					{
						rcnt++;
						m_RightShiftTabs = true;
					}
					#endregion

					#region   
					m_points[0] = new Point ( x - delta, pb.ClientSize.Height);
					m_points[3] = new Point ( (int)(x + w + delta), pb.ClientSize.Height);
					m_points[1] = new Point ( x + delta, pb.ClientSize.Height - m_TabHeight );
					m_points[2] = new Point ( (int)(x - delta + w), pb.ClientSize.Height - m_TabHeight );
								
					rfshift.Y += 3;
				
					if ( m_ActiveTabIndex == i )
					{
						m_Gr.FillPolygon ( Brushes.White, m_points );
						m_Gr.DrawString ( ti.Name, FontTabActive, Brushes.Black, rfshift );
					}
					else
					{
						Brush back = Brushes.White;
						if ( ti.ToBlink )
							if ( ti.Highlighted )
								back = Brushes.LightSteelBlue;
					
						m_Gr.DrawString ( ti.Name, FontTabInactive, back, rfshift );
					}		
					#endregion
				}

				#region   
				Color cshift = CGraphic.GetLighterColor ( pb.BackColor, 3f / 4 );
				Brush b = new SolidBrush ( pb.BackColor );
				Brush bshift = new SolidBrush ( cshift );

				if ( m_LeftShiftTabs )
				{	
					m_Gr.FillRectangle ( b, - 2, pb.ClientSize.Height - m_TabHeight - 1, 26, m_TabHeight + 2 );

					Point ctp = new Point ( 3, pb.ClientSize.Height - m_TabHeight / 2 - 2 );
					Point[] tr = new Point [ 3 ];
				
					tr [ 0 ] = new Point ( ctp.X, ctp.Y );
					tr [ 1 ] = new Point ( ctp.X + 6, ctp.Y - 3 );
					tr [ 2 ] = new Point ( ctp.X + 6, ctp.Y + 3 );

					m_Gr.FillPolygon ( bshift, tr );
				
					Rectangle rr = new Rectangle ( ctp.X + 7, ctp.Y - 6, 17, 10 );
					Font fnt = CGraphic.GetFont ( 6.5F );				
					m_Gr.DrawString ( lcnt.ToString(), fnt, bshift, rr, ClientStatic.SF_NearCenter_dots );
					fnt.Dispose ( );
				}
				else
				{
					Point ctp = new Point ( 2, pb.ClientSize.Height - m_TabHeight / 2 - 2 );				
					m_Gr.FillRectangle ( b, ctp.X - 1, ctp.Y - 4, ctp.X + 7, ctp.Y + 4 );			
				}

				if ( m_RightShiftTabs )
				{
					m_Gr.FillRectangle ( b, pb.ClientSize.Width - 24, pb.ClientSize.Height - m_TabHeight - 1, 26, m_TabHeight + 2 );				

					Point ctp = new Point ( pb.ClientSize.Width - 3, pb.ClientSize.Height - m_TabHeight / 2 - 2 );
					Point[] tr = new Point [ 3 ];
				
					tr [ 0 ] = new Point ( ctp.X, ctp.Y );
					tr [ 1 ] = new Point ( ctp.X - 6, ctp.Y - 3 );
					tr [ 2 ] = new Point ( ctp.X - 6, ctp.Y + 3 );

					m_Gr.FillPolygon ( bshift, tr );

					Rectangle rr = new Rectangle ( ctp.X - 7 - 17, ctp.Y - 6, 17, 10 );
					Font fnt = CGraphic.GetFont ( 6.5F );
					m_Gr.DrawString ( rcnt.ToString(), fnt, bshift, rr, ClientStatic.SF_FarCenter_dots );
					fnt.Dispose ( );
				}
				else
				{
					Point ctp = new Point ( pb.ClientSize.Width - 5, pb.ClientSize.Height - m_TabHeight / 2 );
					m_Gr.FillRectangle ( b, ctp.X + 1, ctp.Y - 4, ctp.X - 7, ctp.Y + 4 );
				}
				
				bshift.Dispose ( );
				b.Dispose ( );
				#endregion
			}
			catch ( Exception ex )
			{
				ClientStatic.Log ( ex );
			}
		}

		private void DrawCross ( )
		{			
			m_Gr.DrawLine ( Pens.White, this.Width - dstx - w1, dsty - w1, this.Width - dstx + w1, dsty + w1 );
			m_Gr.DrawLine ( Pens.White, this.Width - dstx - w1, dsty + w1, this.Width - dstx + w1, dsty - w1 );
		}

		private void DrawMin ( )
		{
			if ( m_MaxButton )
			{				
				m_Gr.DrawRectangle ( Pens.White, this.Width - dstx - minoffset - w1, dsty - w1, w1 * 2, w1 * 2 );
			}

			if ( m_MinButton )
			{	
				int offsextra = m_MaxButton ? minoffset : 0;
				m_Gr.DrawLine ( Pens.White, this.Width - dstx - minoffset - offsextra - w1, dsty + w1, this.Width - dstx - minoffset - offsextra + w1, dsty + w1 );
			}
		}

		#endregion

		#region Public methods
		public int TabCount
		{
			get { return m_TABS.Count; }
		}
		
		public void AddTab(string tabname)
		{
			SizeF sz = m_Gr.MeasureString ( tabname, m_TabUnactiveFont, 1000 );
			RectangleF r;
			if ( m_TABS.Count == 0 )			
				r = new RectangleF ( new PointF ( m_FirstTabOffset+m_BorderWidth, pb.ClientSize.Height - 17 ), sz );
			else			
			{
				CTabInfo last = m_TABS [ m_TABS.Count - 1 ] as CTabInfo;
				r = new RectangleF ( new PointF ( last.Rect.Right + 2 * m_BorderWidth + m_Zazor, pb.ClientSize.Height - 17 ), sz ); 
			}
						
			m_RightBound = (int)( r.Right + 2 * m_BorderWidth );

			CTabInfo ti = new CTabInfo ( tabname, r );			
			m_TABS.Add ( ti );
			
			if ( m_TABS.Count == 1 )
				m_ActiveTabIndex = 0;
			
			BuildTabsRect();
			//DrawControl ( );
			AutoDrawControl();
		}
		
		public void RemoveTab ( int index )
		{
			if ( m_TABS.Count < index )
				return;

			CTabInfo ti = m_TABS [ index ] as CTabInfo;
			m_TABS.RemoveAt ( index );
						
			for ( int k = index; k < m_TABS.Count; k++ )
			{
				CTabInfo tni = m_TABS [ k ] as CTabInfo;
				tni.Rect.X -= ( ti.Rect.Width + 2 * m_BorderWidth + m_Zazor );				
			}
		
			if ( m_TABS.Count > 0 )
			{
				CTabInfo tni2 = m_TABS [ m_TABS.Count - 1 ] as CTabInfo;
				m_RightBound = m_TABS.Count == 0 ? m_MaxOffset : (int)(tni2.Rect.Right + 2 * m_BorderWidth);
			}
			else
				m_RightBound = m_MaxOffset;
			
			if ( index == m_ActiveTabIndex )
			{
				m_ActiveTabIndex --;
				if ( m_ActiveTabIndex < 0 )
					if ( m_TABS.Count > 0 )
						m_ActiveTabIndex = 0;
				
				OnTabChange ( );
			}
			else if ( index < m_ActiveTabIndex )
				m_ActiveTabIndex --;

			BuildTabsRect();
			//DrawControl ( );
			AutoDrawControl();
		}
		
		public void DeleteTab(string tabname)
		{
			for ( int i = 0; i < m_TABS.Count; i++ )
			{
				CTabInfo ti = m_TABS [ i ] as CTabInfo;
				if ( ti.Name == tabname )
				{
					RemoveTab ( i );
					break;
				}
			}
		}
		
		public void ClearTabs()
		{			
			m_TABS.Clear ( );
			m_RightBound = m_MaxOffset;
			m_ScrollOffsX = 0;
			m_ActiveTabIndex = -1;
			//DrawControl();
			AutoDrawControl();
		}

		public void ShiftRects ( )
		{
			for ( int i = 0; i < m_TABS.Count; i++ )
			{
				CTabInfo ti = m_TABS [ i ] as CTabInfo;
				if ( ti.Rect.Top != pb.ClientSize.Height - 17 )
					ti.Rect.Offset ( 0, pb.ClientSize.Height - 17 - ti.Rect.Top );				
			}
		}

		public void BlinkStart ( int id )
		{
			if ( m_TABS.Count <= id )
				return;

			CTabInfo ti = m_TABS [ id ] as CTabInfo;
			ti.ToBlink = true;
			ti.Highlighted = false;

			if ( m_BlinkTimer == null )
			{
				m_BlinkTimer = new Timer ( );
				m_BlinkTimer.Interval = 500;
				m_BlinkTimer.Tick += new EventHandler(m_BlinkTimer_Tick);				
			}

			m_BlinkTimer.Start ( );
		}
		public void BlinkStop ( int id )
		{			
			if ( m_TABS.Count <= id )
				return;

			CTabInfo ti = m_TABS [ id ] as CTabInfo;
			ti.ToBlink = false;
			ti.Highlighted = false;

			for ( int i = 0; i < m_TABS.Count; i++ )
			{
				CTabInfo tni = m_TABS [ i ] as CTabInfo;
				if ( tni.ToBlink )
					return;
			}

			if ( m_BlinkTimer != null )
				m_BlinkTimer.Stop ( );
			DrawBackTabs ( );
			DrawTabs ( );
			Invalidate ( );
		}		
		public void BlinkStopAll ( ) 
		{
			for ( int i = 0; i < m_TABS.Count; i++ )
			{
				CTabInfo ti = m_TABS [ i ] as CTabInfo;
				ti.ToBlink = false;
				ti.Highlighted = false;					
			}
			
			if ( m_BlinkTimer != null )
				m_BlinkTimer.Stop ( );
			DrawBackTabs ( );
			DrawTabs ( );
			Invalidate ( );
		}
		public void RefreshLeftOffset ( )
		{
			m_FirstTabOffset = m_MaxOffset;
			DrawBackTabs ( );
			DrawTabs ( );
			Invalidate ( );
		}
		#endregion

		public void Redraw ( )
		{
			DrawControl();

			if ( m_Bmp != null )
				pb.Image = m_Bmp;

			pb.Invalidate ( );			
		}
		
		#region Overrides
		protected override void OnBackColorChanged(EventArgs e)
		{
			base.OnBackColorChanged (e);

			try
			{
				pb.BackColor = this.BackColor;
				//DrawControl();
				AutoDrawControl();
			}
			catch ( Exception ex )
			{
				ClientStatic.Log ( ex );
			}
		}

		protected override void OnResize(EventArgs e)
		{
			base.OnResize (e);

			try
			{
				if (( pb.ClientSize.Width <= 0 ) || ( pb.ClientSize.Height <= 0))
					return;

				if (( Dock != DockStyle.Top ) && ( m_AutoMakeTop ))
					Dock = DockStyle.Top;
			
				pb.Image = null;
				if (m_Bmp != null)
				{
					m_Bmp.Dispose();
					m_Bmp = null;
				}
				if (m_Gr != null)
				{
					m_Gr.Dispose();
					m_Gr = null;
				}
			
				if (pb.ClientSize.Width == 0 || pb.ClientSize.Height == 0 )
					return;

				m_Bmp = new Bitmap ( pb.ClientSize.Width, pb.ClientSize.Height );
				m_Gr = Graphics.FromImage(m_Bmp);
				m_Gr.TextRenderingHint = CGraphic.TextRenderingHint;
				m_Gr.SmoothingMode  = SmoothingMode.AntiAlias;

				SizeF sz = m_Gr.MeasureString ( "WhpgYj", FontCaption, 200 );
				m_StrRect = new RectangleF(15, ( pb.ClientSize.Height - (int) Math.Ceiling ( sz.Height ) ) / 2, pb.ClientSize.Width - 30, (int) Math.Ceiling ( sz.Height ) );
			
				BuildTabsRect();

				pb.Image = m_Bmp;

				//DrawControl();
				AutoDrawControl();
			}
			catch ( Exception ex )
			{
				ClientStatic.Log ( ex );
			}
		}

		#endregion

		private bool m_CanMaximize = false;
		private void pb_DoubleClick(object sender, System.EventArgs e)
		{
			if ( m_CanMaximize )
			{
				Type t = this.ParentForm.GetType ( );
				MethodInfo mi = t.GetMethod ( "Maximize" );
				if ( mi != null )							
					mi.Invoke ( ParentForm, null );
			}
		}

		private void m_BlinkTimer_Tick(object sender, EventArgs e)
		{
			for ( int i = 0; i < m_TABS.Count; i++ )
			{
				CTabInfo ti = m_TABS [ i ] as CTabInfo;
				if ( ti.ToBlink )
					ti.Highlighted = ! ti.Highlighted;
			}

			if ( ! ParentForm.Visible )
				return;
			
			if ( ParentForm.WindowState == FormWindowState.Minimized )
				return;

			DrawBackTabs ( );
			DrawTabs ( );
			Invalidate ( );
			Refresh ( );
		}

		private void pb_MouseMove(object sender, System.Windows.Forms.MouseEventArgs e)
		{
			//   
			ClientStatic.CursorClearToControl ( this );
		}

		
		#region  
		private oktellControlBox ctrlBox = new oktellControlBox ();
		private void UpdateCtrlBox()
		{
			int BtnCount = 1;
			
			if (m_MaxButton)
				BtnCount++;
			
			if (m_MinButton)
				BtnCount++;

			oktellControlBox.ControlButton[] btns = new oktellControlBox.ControlButton[BtnCount];
			oktellControlBox.ControlButton btn;

			int i = 0;

			#region 

			#region 
			btn = new oktellControlBox.ControlButton();
			btn.ButtonUp = XmlResource.GetImageByName ( "ICON_frameup_close14" );
			btn.ButtonOver = XmlResource.GetImageByName ( "ICON_frameover_close14" );
			btn.ButtonDown = XmlResource.GetImageByName ( "ICON_framedown_close14" );
			btn.Tag = "close";
			btn.Hint = "";
			btns[i] = btn;
			i++;
			#endregion

			#region 
			if (m_MaxButton)
			{
				btn = new oktellControlBox.ControlButton();
				btn.ButtonUp = XmlResource.GetImageByName ( "ICON_frameup_maximize14" );
				btn.ButtonOver = XmlResource.GetImageByName ( "ICON_frameover_maximize14" );
				btn.ButtonDown = XmlResource.GetImageByName ( "ICON_framedown_maximize14" );
				btn.Tag = "maximize";
				btn.Hint = "";
				btns[i] = btn;
				i++;
			}
			#endregion

			#region 
			if (m_MinButton)
			{
				btn = new oktellControlBox.ControlButton();
				btn.ButtonUp = XmlResource.GetImageByName ( "ICON_frameup_minimize14" );
				btn.ButtonOver = XmlResource.GetImageByName ( "ICON_frameover_minimize14" );
				btn.ButtonDown = XmlResource.GetImageByName ( "ICON_framedown_minimize14" );
				btn.Tag = "minimize";
				btn.Hint = "";
				btns[i] = btn;
				i++;
			}
			#endregion

			ctrlBox.Buttons = btns;
			#endregion

			ctrlBox.ButtonSize = 14;
			ctrlBox.ButtonMargin = 1;
			int wdth = ctrlBox.Buttons.Length*ctrlBox.ButtonSize+(ctrlBox.Buttons.Length-1)*ctrlBox.ButtonMargin;
			int hght = ctrlBox.ButtonSize;
			int top = 2;
			int left = pb.Width - 2 - wdth;
			ctrlBox.Bounds = new Rectangle ( left, top, wdth, hght );

			if (ctrlBox.Parent != pb)
				ctrlBox.Parent = pb;
		}

		private void ctrlBox_OnButtonClick(object sender, EventArgs e)
		{
			oktellControlBox.ControlButton btn = sender as oktellControlBox.ControlButton;
			switch (btn.Tag as string)
			{
				case "close":
					if ( OnCrossClicked != null )
						OnCrossClicked ( this, EventArgs.Empty );
					else
						ParentForm.Close ( );
					break;

				case "maximize":
					Type t = this.ParentForm.GetType ( );
					MethodInfo mi = t.GetMethod ( "Maximize" );
					if ( mi != null )							
						mi.Invoke ( ParentForm, null );
					break;

				case "minimize":
					this.ParentForm.WindowState = FormWindowState.Minimized;
					break;
			}
		}
		#endregion

		#region VisibleChanged
		private void AutoDrawControl ( )
		{
			if ( this.Visible && pb.Visible )
			{
				DrawControl();
				pb.Invalidate();
			}
			else
			{
				m_ShouldRedraw = true;
			}
		}
		
		private volatile bool m_ShouldRedraw = false;
		private void pb_VisibleChanged(object sender, EventArgs e)
		{
			if ( ! pb.Visible )
				return;
			if ( ! m_ShouldRedraw )
				return;
			
			m_ShouldRedraw = false;
			
			//DrawControl();
			//pb.Invalidate();
			AutoDrawControl();
		}

		private void oktellSmallTabPanel_VisibleChanged(object sender, EventArgs e)
		{
			if ( ! pb.Visible )
				return;
			if ( ! m_ShouldRedraw )
				return;
			
			m_ShouldRedraw = false;
			
			//DrawControl();
			//pb.Invalidate();
			AutoDrawControl();
		}
		#endregion
	}	

	public class ExcelImportForm : oktellForm
	{
		private oktellClient.Controls.oktellBevel oktellBevel1;
		private oktellClient.Controls.oktellButton btnOk;
		private oktellClient.Controls.oktellButton btnCancel;
		private oktellButtonEdit2 bteFileName;
		private System.Windows.Forms.Label oktellLabel1;
		private oktellClient.Controls.oktellComboBox2 cbxListsNames;
		private System.Windows.Forms.Label oktellLabel2;
		private System.ComponentModel.Container components = null;
		private oktellClient.Controls.oktellSmallTabPanel HeaderTab;

		private EColorGroup m_ColorGroup = EColorGroup.cgOffice;
		public ExcelImportForm()
		{
			InitializeComponent();

			#region Colors
			HeaderTab.BackColor = ClientColors.c_MainColor [ (int) m_ColorGroup ];

			btnOk.BackColor = ClientColors.c_ButtonBackColor [ (int) m_ColorGroup ];
			btnOk.BackColor2 = ClientColors.c_ButtonBackTopColor [ (int) m_ColorGroup ]; 
			btnOk.BackColor3 = ClientColors.c_ButtonBackTopDownColor [ (int) m_ColorGroup ];
			btnOk.BorderColor = ClientColors.c_ButtonBorderColor [ (int) m_ColorGroup ];
			
			btnCancel.BackColor = ClientColors.c_ButtonBackColor [ (int) m_ColorGroup ];
			btnCancel.BackColor2 = ClientColors.c_ButtonBackTopColor [ (int) m_ColorGroup ]; 
			btnCancel.BackColor3 = ClientColors.c_ButtonBackTopDownColor [ (int) m_ColorGroup ];
			btnCancel.BorderColor = ClientColors.c_ButtonBorderColor [ (int) m_ColorGroup ];
			
			bteFileName.ColorGroup = m_ColorGroup;
			bteFileName.UseColorGroup = true;

			cbxListsNames.MainColor = ClientColors.c_MainColor [ (int) m_ColorGroup ];
			cbxListsNames.Properties.Appearance.BorderColor = ClientColors.c_MainColor [ (int) m_ColorGroup ];
			cbxListsNames.Properties.AppearanceDisabled.BackColor = System.Drawing.Color.FromArgb(((System.Byte)(235)), ((System.Byte)(240)), ((System.Byte)(220)));			
			cbxListsNames.Properties.AppearanceDropDown.BorderColor = ClientColors.c_MainColor [ (int) m_ColorGroup ];
			
			#endregion
		}

		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			this.HeaderTab = new oktellClient.Controls.oktellSmallTabPanel();
			this.btnOk = new oktellClient.Controls.oktellButton();
			this.btnCancel = new oktellClient.Controls.oktellButton();
			this.oktellBevel1 = new oktellClient.Controls.oktellBevel();
			this.oktellLabel1 = new System.Windows.Forms.Label();
			this.cbxListsNames = new oktellClient.Controls.oktellComboBox2();
			this.oktellLabel2 = new System.Windows.Forms.Label();
			((System.ComponentModel.ISupportInitialize)(this.bteFileName.Properties)).BeginInit();
			((System.ComponentModel.ISupportInitialize)(this.cbxListsNames.Properties)).BeginInit();
			this.SuspendLayout();
			// 
			// HeaderTab
			// 
			this.HeaderTab.ActiveTabIndex = -1;
			this.HeaderTab.BackColor = System.Drawing.Color.FromArgb(((System.Byte)(186)), ((System.Byte)(74)), ((System.Byte)(67)));
			this.HeaderTab.Caption = "  Excel";
			this.HeaderTab.CenterText = false;
			this.HeaderTab.Dock = System.Windows.Forms.DockStyle.Top;
			this.HeaderTab.Font = new System.Drawing.Font("Microsoft Sans Serif", 11F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Pixel);
			this.HeaderTab.FontCaption = new System.Drawing.Font("Microsoft Sans Serif", 15F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(204)));
			this.HeaderTab.FontTabActive = new System.Drawing.Font("Microsoft Sans Serif", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(204)));
			this.HeaderTab.FontTabInactive = new System.Drawing.Font("Microsoft Sans Serif", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(204)));
			this.HeaderTab.Location = new System.Drawing.Point(0, 0);
			this.HeaderTab.MaxButton = false;
			this.HeaderTab.MinButton = false;
			this.HeaderTab.Name = "HeaderTab";
			this.HeaderTab.Size = new System.Drawing.Size(478, 50);
			this.HeaderTab.TabIndex = 0;
			this.HeaderTab.OnCrossClicked += new System.EventHandler(this.HeaderTab_OnCrossClicked);
			// 
			// btnOk
			// 
			this.btnOk.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Right)));
			this.btnOk.BackColor = System.Drawing.Color.FromArgb(((System.Byte)(236)), ((System.Byte)(223)), ((System.Byte)(224)));
			this.btnOk.BackColor2 = System.Drawing.Color.FromArgb(((System.Byte)(247)), ((System.Byte)(241)), ((System.Byte)(241)));
			this.btnOk.BackColor3 = System.Drawing.Color.White;
			this.btnOk.BorderColor = System.Drawing.Color.FromArgb(((System.Byte)(186)), ((System.Byte)(74)), ((System.Byte)(67)));
			this.btnOk.ColorGroup = oktellClient.Controls.EColorGroup.cgOffice;
			this.btnOk.DialogResult = System.Windows.Forms.DialogResult.OK;
			this.btnOk.Font = new System.Drawing.Font("Microsoft Sans Serif", 11F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Pixel);
			this.btnOk.Image = null;
			this.btnOk.Location = new System.Drawing.Point(256, 261);
			this.btnOk.Name = "btnOk";
			this.btnOk.Size = new System.Drawing.Size(96, 24);
			this.btnOk.SmoothingMode = System.Drawing.Drawing2D.SmoothingMode.HighQuality;
			this.btnOk.TabIndex = 9;
			this.btnOk.Text = "OK";
			this.btnOk.UseColorGroup = false;
			this.btnOk.Click += new System.EventHandler(this.btnOk_Click);
			// 
			// btnCancel
			// 
			this.btnCancel.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Right)));
			this.btnCancel.BackColor = System.Drawing.Color.FromArgb(((System.Byte)(236)), ((System.Byte)(223)), ((System.Byte)(224)));
			this.btnCancel.BackColor2 = System.Drawing.Color.FromArgb(((System.Byte)(247)), ((System.Byte)(241)), ((System.Byte)(241)));
			this.btnCancel.BackColor3 = System.Drawing.Color.White;
			this.btnCancel.BorderColor = System.Drawing.Color.FromArgb(((System.Byte)(186)), ((System.Byte)(74)), ((System.Byte)(67)));
			this.btnCancel.ColorGroup = oktellClient.Controls.EColorGroup.cgOffice;
			this.btnCancel.DialogResult = System.Windows.Forms.DialogResult.Cancel;
			this.btnCancel.Font = new System.Drawing.Font("Microsoft Sans Serif", 11F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Pixel);
			this.btnCancel.Image = null;
			this.btnCancel.Location = new System.Drawing.Point(360, 261);
			this.btnCancel.Name = "btnCancel";
			this.btnCancel.Size = new System.Drawing.Size(96, 24);
			this.btnCancel.SmoothingMode = System.Drawing.Drawing2D.SmoothingMode.HighQuality;
			this.btnCancel.TabIndex = 8;
			this.btnCancel.Text = "";
			this.btnCancel.UseColorGroup = false;
			// 
			// oktellBevel1
			// 
			this.oktellBevel1.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Left) 
				| System.Windows.Forms.AnchorStyles.Right)));
			this.oktellBevel1.BevelType = oktellClient.Controls.EBevelType.LineBottom;
			this.oktellBevel1.LineColor = System.Drawing.Color.Gray;
			this.oktellBevel1.LineDashStyle = System.Drawing.Drawing2D.DashStyle.Solid;
			this.oktellBevel1.LineMargin = 0;
			this.oktellBevel1.Location = new System.Drawing.Point(0, 244);
			this.oktellBevel1.Name = "oktellBevel1";
			this.oktellBevel1.Size = new System.Drawing.Size(480, 1);
			this.oktellBevel1.TabIndex = 10;
			this.oktellBevel1.Text = "oktellBevel1";
			// 
			// bteFileName
			// 
			this.bteFileName.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Left) 
				| System.Windows.Forms.AnchorStyles.Right)));
			this.bteFileName.EditValue = "";
			this.bteFileName.Location = new System.Drawing.Point(32, 96);
			this.bteFileName.Name = "bteFileName";
			// 
			// bteFileName.Properties
			// 
			this.bteFileName.Properties.AllowFocused = false;
			this.bteFileName.Properties.Appearance.BackColor = System.Drawing.Color.White;
			this.bteFileName.Properties.Appearance.BorderColor = System.Drawing.Color.FromArgb(((System.Byte)(186)), ((System.Byte)(74)), ((System.Byte)(67)));
			this.bteFileName.Properties.Appearance.Font = new System.Drawing.Font("Microsoft Sans Serif", 11F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Pixel);
			this.bteFileName.Properties.Appearance.Options.UseBackColor = true;
			this.bteFileName.Properties.Appearance.Options.UseBorderColor = true;
			this.bteFileName.Properties.Appearance.Options.UseFont = true;
			this.bteFileName.Properties.AppearanceDisabled.BackColor = System.Drawing.Color.FromArgb(((System.Byte)(241)), ((System.Byte)(241)), ((System.Byte)(230)));
			this.bteFileName.Properties.AppearanceDisabled.BorderColor = System.Drawing.Color.FromArgb(((System.Byte)(191)), ((System.Byte)(186)), ((System.Byte)(111)));
			this.bteFileName.Properties.AppearanceDisabled.Options.UseBackColor = true;
			this.bteFileName.Properties.AppearanceDisabled.Options.UseBorderColor = true;
			this.bteFileName.Properties.AutoHeight = false;
			this.bteFileName.Size = new System.Drawing.Size(416, 19);
			this.bteFileName.TabIndex = 11;
			this.bteFileName.EditValueChanged += new System.EventHandler(this.bteFileName_EditValueChanged);
			// 
			// oktellLabel1
			// 
			this.oktellLabel1.AutoSize = true;
			this.oktellLabel1.Font = new System.Drawing.Font("Microsoft Sans Serif", 11F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Pixel);
			this.oktellLabel1.Location = new System.Drawing.Point(32, 72);
			this.oktellLabel1.Name = "oktellLabel1";
			this.oktellLabel1.Size = new System.Drawing.Size(161, 16);
			this.oktellLabel1.TabIndex = 12;
			this.oktellLabel1.Text = "   :";
			// 
			// cbxListsNames
			// 
			this.cbxListsNames.EditValue = "";
			this.cbxListsNames.HighLightColor = System.Drawing.Color.FromArgb(((System.Byte)(221)), ((System.Byte)(165)), ((System.Byte)(162)));
			this.cbxListsNames.Location = new System.Drawing.Point(32, 160);
			this.cbxListsNames.MainColor = System.Drawing.Color.FromArgb(((System.Byte)(186)), ((System.Byte)(74)), ((System.Byte)(67)));
			this.cbxListsNames.Name = "cbxListsNames";
			// 
			// cbxListsNames.Properties
			// 
			this.cbxListsNames.Properties.AllowFocused = false;
			this.cbxListsNames.Properties.Appearance.BorderColor = System.Drawing.Color.FromArgb(((System.Byte)(186)), ((System.Byte)(74)), ((System.Byte)(67)));
			this.cbxListsNames.Properties.Appearance.Font = new System.Drawing.Font("Microsoft Sans Serif", 11F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Pixel);
			this.cbxListsNames.Properties.Appearance.Options.UseBorderColor = true;
			this.cbxListsNames.Properties.Appearance.Options.UseFont = true;
			this.cbxListsNames.Properties.AppearanceDisabled.BackColor = System.Drawing.Color.FromArgb(((System.Byte)(235)), ((System.Byte)(240)), ((System.Byte)(220)));
			this.cbxListsNames.Properties.AppearanceDisabled.BorderColor = System.Drawing.Color.FromArgb(((System.Byte)(186)), ((System.Byte)(74)), ((System.Byte)(67)));
			this.cbxListsNames.Properties.AppearanceDisabled.Options.UseBackColor = true;
			this.cbxListsNames.Properties.AppearanceDisabled.Options.UseBorderColor = true;
			this.cbxListsNames.Properties.AppearanceDropDown.BorderColor = System.Drawing.Color.FromArgb(((System.Byte)(186)), ((System.Byte)(74)), ((System.Byte)(67)));
			this.cbxListsNames.Properties.AppearanceDropDown.Options.UseBorderColor = true;
			this.cbxListsNames.Properties.AutoHeight = false;
			this.cbxListsNames.Properties.DropDownRows = 20;
			this.cbxListsNames.Properties.ShowPopupShadow = false;
			this.cbxListsNames.Size = new System.Drawing.Size(416, 19);
			this.cbxListsNames.TabIndex = 13;
			this.cbxListsNames.UseLeftDots = false;
			// 
			// oktellLabel2
			// 
			this.oktellLabel2.AutoSize = true;
			this.oktellLabel2.Font = new System.Drawing.Font("Microsoft Sans Serif", 11F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Pixel);
			this.oktellLabel2.Location = new System.Drawing.Point(32, 136);
			this.oktellLabel2.Name = "oktellLabel2";
			this.oktellLabel2.Size = new System.Drawing.Size(207, 16);
			this.oktellLabel2.TabIndex = 14;
			this.oktellLabel2.Text = ",    :";
			// 
			// ExcelImportForm
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.BackColor = System.Drawing.Color.White;
			this.CancelButton = this.btnCancel;
			this.ClientSize = new System.Drawing.Size(478, 302);
			this.ControlBox = false;
			this.Controls.Add(this.oktellLabel2);
			this.Controls.Add(this.oktellLabel1);
			this.Controls.Add(this.cbxListsNames);
			this.Controls.Add(this.bteFileName);
			this.Controls.Add(this.oktellBevel1);
			this.Controls.Add(this.btnOk);
			this.Controls.Add(this.btnCancel);
			this.Controls.Add(this.HeaderTab);
			this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedToolWindow;
			this.MaximizeBox = false;
			this.MinimizeBox = false;
			this.Name = "ExcelImportForm";
			this.ShowInTaskbar = false;
			this.StartPosition = System.Windows.Forms.FormStartPosition.CenterScreen;
			this.Load += new System.EventHandler(this.ExcelImportForm_Load);
			this.VisibleChanged += new System.EventHandler(this.ExcelImportForm_VisibleChanged);
			((System.ComponentModel.ISupportInitialize)(this.bteFileName.Properties)).EndInit();
			((System.ComponentModel.ISupportInitialize)(this.cbxListsNames.Properties)).EndInit();
			this.ResumeLayout(false);

		}
		#endregion

//		private void bteFileName_Properties_ButtonClick(object sender, DevExpress.XtraEditors.Controls.ButtonPressedEventArgs e)
//		{
//			OpenFileDialog ofd = new OpenFileDialog();
//			ofd.Title = "";
//			ofd.ReadOnlyChecked = true;
//			ofd.Multiselect = false;
//			ofd.Filter = " Microsoft Excel (*.xls)|*.xls";
//				
//			if ( ofd.ShowDialog ( this ) == DialogResult.OK )
//				bteFileName.Text = ofd.FileName;
//		}

		private DataTable m_Table = null;

		private void HeaderTab_OnCrossClicked(object sender, System.EventArgs e)
		{
			Close();
		}

		private void btnOk_Click(object sender, System.EventArgs e)
		{
			if (cbxListsNames.SelectedIndex >= 0 && !bteFileName.Text.Equals(string.Empty))
			{
				OleDbConnection conn = new OleDbConnection("Provider=Microsoft.Jet.OLEDB.4.0; Data Source=" + bteFileName.Text + "; Extended Properties=\"Excel 8.0; HDR=Yes\";");
				
				OleDbCommand cmd = new OleDbCommand();
				cmd.CommandText = "Select * from ["+cbxListsNames.Text+"]";
				cmd.CommandType = CommandType.Text;
				cmd.Connection = conn;

				OleDbDataAdapter adapter = new OleDbDataAdapter(cmd);
				
				m_Table = new DataTable();
				
				conn.Open();
				try
				{
					adapter.Fill(m_Table);
				}
				finally
				{
					conn.Close();
				}
			}
		}

		private void ExcelImportForm_VisibleChanged(object sender, System.EventArgs e)
		{
			if (Visible)
				bteFileName.Text = "";
		}

		public ArrayList GetTables(string fileName)
		{
			ArrayList a = new ArrayList();
			OleDbConnection conn = new OleDbConnection("Provider=Microsoft.Jet.OLEDB.4.0; Data Source="+fileName+"; Extended Properties=Excel 8.0;");
			conn.Open();
			try
			{
				DataTable schemaTable = conn.GetOleDbSchemaTable(OleDbSchemaGuid.Tables,
					new object[] {null, null, null, "TABLE"});

				foreach(DataRow row in schemaTable.Rows)
					a.Add(row[2]);
			}
			catch(Exception ex)
			{
				ClientStatic.Log(ex);
			}
			finally
			{
				conn.Close();
			}
			return a;
		}

		private void bteFileName_EditValueChanged(object sender, System.EventArgs e)
		{
			if (!bteFileName.Text.Equals(string.Empty))
			{
				cbxListsNames.Properties.Items.BeginUpdate();
				cbxListsNames.Properties.Items.Clear();
				cbxListsNames.Properties.Items.AddRange(GetTables(bteFileName.Text));
				if (cbxListsNames.Properties.Items.Count > 0)
					cbxListsNames.SelectedIndex = 0;
				cbxListsNames.Properties.Items.EndUpdate();
			}
		}

		private void ExcelImportForm_Load(object sender, System.EventArgs e)
		{
		
		}

	
		public DataTable Table 
		{
			get
			{
				return m_Table;
			}
		}
	}
}
